export async function loadScriptWithExport({
  src,
  name,
  id,
  exportedName,
}: {
  src: string;
  id?: string;
  name: string;
  exportedName?: string;
}) {
  return await new Promise((resolve, reject) => {
    let script = document.createElement("script");
    script.type = "text/javascript";
    script.src = src;
    if (id) {
      script.id = id;
    }
    script.addEventListener("load", async () => {
      if (exportedName) {
        const exportedSymbol = exportedName
          .split(".")
          .reduce((result, key: string) => result?.[key], window as any); // `window as any` helps TypeScript understand it can index window
        resolve(exportedSymbol);
      } else {
        resolve(undefined);
      }
    });
    script.addEventListener("error", () => {
      reject(new Error("Failed to load fastlane."));
    });
    script.addEventListener("abort", () => {
      reject(new Error("fastlane load was aborted."));
    });

    document.getElementsByTagName("head")[0].appendChild(script);
  });
}
